require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_officeonlineserverproductupdate',
  dscmeta_resource_friendly_name: 'OfficeOnlineServerProductUpdate',
  dscmeta_resource_name: 'MSFT_OfficeOnlineServerProductUpdate',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'OfficeOnlineServerDsc',
  dscmeta_module_version: '1.5.0',
  docs: 'The DSC OfficeOnlineServerProductUpdate resource type.
         Automatically generated from version 1.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_setupfile: {
      type: 'String',
      desc: 'The name of the update setup file',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_servers: {
      type: 'Array[String]',
      desc: 'List of servers in the Office Online Server farm',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_installaccount: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'POWERSHELL 4 ONLY: The account to run this resource as, use PsDscRunAsCredential if using PowerShell 5',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present to install Update. Absent is currently not supported',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
